Using Plugins
=============

* Enable the plugin for a given ticket folder::

    jirafs plugins --enable=my_plugin_name

* Enable the plugin globally::

    jirafs plugins --global --enable=my_plugin_name

.. toctree::
   :maxdepth: 2

   writing_plugins
